package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcWljg;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcAqgMapper;
import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.service.ITcAqgService;

/**
 * 网络安全官Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
@Service
public class TcAqgServiceImpl implements ITcAqgService 
{
    @Autowired
    private TcAqgMapper tcAqgMapper;

    /**
     * 查询网络安全官
     * 
     * @param id 网络安全官主键
     * @return 网络安全官
     */
    @Override
    public TcAqg selectTcAqgById(Long id)
    {
        return tcAqgMapper.selectTcAqgById(id);
    }

    /**
     * 查询网络安全官列表
     * 
     * @param tcAqg 网络安全官
     * @return 网络安全官
     */
    @Override
    public List<TcAqg> selectTcAqgList(TcAqg tcAqg)
    {
        return tcAqgMapper.selectTcAqgList(tcAqg);
    }

    /**
     * 新增网络安全官
     * 
     * @param tcAqg 网络安全官
     * @return 结果
     */
    @Override
    public int insertTcAqg(TcAqg tcAqg)
    {
        tcAqg.setCreateTime(DateUtils.getNowDate());
        return tcAqgMapper.insertTcAqg(tcAqg);
    }

    /**
     * 修改网络安全官
     * 
     * @param tcAqg 网络安全官
     * @return 结果
     */
    @Override
    public int updateTcAqg(TcAqg tcAqg)
    {
        tcAqg.setUpdateTime(DateUtils.getNowDate());
        return tcAqgMapper.updateTcAqg(tcAqg);
    }

    /**
     * 批量删除网络安全官
     * 
     * @param ids 需要删除的网络安全官主键
     * @return 结果
     */
    @Override
    public int deleteTcAqgByIds(Long[] ids)
    {
        return tcAqgMapper.deleteTcAqgByIds(ids);
    }

    /**
     * 删除网络安全官信息
     * 
     * @param id 网络安全官主键
     * @return 结果
     */
    @Override
    public int deleteTcAqgById(Long id)
    {
        return tcAqgMapper.deleteTcAqgById(id);
    }

    @Override
    public String importUser(List<TcAqg> tcAqgList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcAqgList.isEmpty()) {
            for (TcAqg tcAqg : tcAqgList) {
                tcAqgMapper.insertTcAqg(tcAqg);
            }
            successMsg.append("导入成功");
        }
        return successMsg.toString();
    }


    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcAqgMapper.updateByisStatus(isStatus,ids);
    }
}
